@@ -43,7 +43,8 @@ def _configure_logging():
   standard_format = logging_config['formatters']['standard']
 
   logging.config.dictConfig(logging_config)
-  coloredlogs.install(fmt=standard_format['format'], datefmt=standard_format['datefmt'])
+  level = logging.getLevelName(logging.getLogger().getEffectiveLevel())
+  coloredlogs.install(level=level, fmt=standard_format['format'], datefmt=standard_format['datefmt'])
 
 
 def error_with_traceback():
